==> slurm_rest_client-0.1.3-py3-none-any.whl: slurm_rest_client/api/slurm/slurm_v0040_delete_job.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.slurm_v0040_delete_job_flags import SlurmV0040DeleteJobFlags
from ...models.slurm_v0040_delete_job_response_200 import SlurmV0040DeleteJobResponse200
from ...types import UNSET, Response, Unset


def _get_kwargs(
    job_id: str,
    *,
    signal: Union[Unset, str] = UNSET,
    flags: Union[Unset, SlurmV0040DeleteJobFlags] = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["signal"] = signal

    json_flags: Union[Unset, str] = UNSET
    if not isinstance(flags, Unset):
        json_flags = flags.value

    params["flags"] = json_flags

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "delete",
        "url": f"/slurm/v0.0.40/job/{job_id}",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[SlurmV0040DeleteJobResponse200]:
    if response.status_code == 200:
        response_200 = SlurmV0040DeleteJobResponse200.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[SlurmV0040DeleteJobResponse200]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    job_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
    signal: Union[Unset, str] = UNSET,
    flags: Union[Unset, SlurmV0040DeleteJobFlags] = UNSET,
) -> Response[SlurmV0040DeleteJobResponse200]:
    """cancel or signal job

    Args:
        job_id (str):
        signal (Union[Unset, str]):
        flags (Union[Unset, SlurmV0040DeleteJobFlags]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[SlurmV0040DeleteJobResponse200]
    """

    kwargs = _get_kwargs(
        job_id=job_id,
        signal=signal,
        flags=flags,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    job_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
    signal: Union[Unset, str] = UNSET,
    flags: Union[Unset, SlurmV0040DeleteJobFlags] = UNSET,
) -> Optional[SlurmV0040DeleteJobResponse200]:
    """cancel or signal job

    Args:
        job_id (str):
        signal (Union[Unset, str]):
        flags (Union[Unset, SlurmV0040DeleteJobFlags]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        SlurmV0040DeleteJobResponse200
    """

    return sync_detailed(
        job_id=job_id,
        client=client,
        signal=signal,
        flags=flags,
    ).parsed


async def asyncio_detailed(
    job_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
    signal: Union[Unset, str] = UNSET,
    flags: Union[Unset, SlurmV0040DeleteJobFlags] = UNSET,
) -> Response[SlurmV0040DeleteJobResponse200]:
    """cancel or signal job

    Args:
        job_id (str):
        signal (Union[Unset, str]):
        flags (Union[Unset, SlurmV0040DeleteJobFlags]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[SlurmV0040DeleteJobResponse200]
    """

    kwargs = _get_kwargs(
        job_id=job_id,
        signal=signal,
        flags=flags,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    job_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
    signal: Union[Unset, str] = UNSET,
    flags: Union[Unset, SlurmV0040DeleteJobFlags] = UNSET,
) -> Optional[SlurmV0040DeleteJobResponse200]:
    """cancel or signal job

    Args:
        job_id (str):
        signal (Union[Unset, str]):
        flags (Union[Unset, SlurmV0040DeleteJobFlags]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        SlurmV0040DeleteJobResponse200
    """

    return (
        await asyncio_detailed(
            job_id=job_id,
            client=client,
            signal=signal,
            flags=flags,
        )
    ).parsed

==> slurm_rest_client-0.1.4-py3-none-any.whl: slurm_rest_client/api/slurm/slurm_v0040_delete_job.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.slurm_v0040_delete_job_flags import SlurmV0040DeleteJobFlags
from ...models.v0040_openapi_resp import V0040OpenapiResp
from ...types import UNSET, Response, Unset


def _get_kwargs(
    job_id: str,
    *,
    signal: Union[Unset, str] = UNSET,
    flags: Union[Unset, SlurmV0040DeleteJobFlags] = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["signal"] = signal

    json_flags: Union[Unset, str] = UNSET
    if not isinstance(flags, Unset):
        json_flags = flags.value

    params["flags"] = json_flags

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "delete",
        "url": f"/slurm/v0.0.40/job/{job_id}",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[V0040OpenapiResp]:
    if response.status_code == 200:
        response_200 = V0040OpenapiResp.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[V0040OpenapiResp]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    job_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
    signal: Union[Unset, str] = UNSET,
    flags: Union[Unset, SlurmV0040DeleteJobFlags] = UNSET,
) -> Response[V0040OpenapiResp]:
    """cancel or signal job

    Args:
        job_id (str):
        signal (Union[Unset, str]):
        flags (Union[Unset, SlurmV0040DeleteJobFlags]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[V0040OpenapiResp]
    """

    kwargs = _get_kwargs(
        job_id=job_id,
        signal=signal,
        flags=flags,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    job_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
    signal: Union[Unset, str] = UNSET,
    flags: Union[Unset, SlurmV0040DeleteJobFlags] = UNSET,
) -> Optional[V0040OpenapiResp]:
    """cancel or signal job

    Args:
        job_id (str):
        signal (Union[Unset, str]):
        flags (Union[Unset, SlurmV0040DeleteJobFlags]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        V0040OpenapiResp
    """

    return sync_detailed(
        job_id=job_id,
        client=client,
        signal=signal,
        flags=flags,
    ).parsed


async def asyncio_detailed(
    job_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
    signal: Union[Unset, str] = UNSET,
    flags: Union[Unset, SlurmV0040DeleteJobFlags] = UNSET,
) -> Response[V0040OpenapiResp]:
    """cancel or signal job

    Args:
        job_id (str):
        signal (Union[Unset, str]):
        flags (Union[Unset, SlurmV0040DeleteJobFlags]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[V0040OpenapiResp]
    """

    kwargs = _get_kwargs(
        job_id=job_id,
        signal=signal,
        flags=flags,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    job_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
    signal: Union[Unset, str] = UNSET,
    flags: Union[Unset, SlurmV0040DeleteJobFlags] = UNSET,
) -> Optional[V0040OpenapiResp]:
    """cancel or signal job

    Args:
        job_id (str):
        signal (Union[Unset, str]):
        flags (Union[Unset, SlurmV0040DeleteJobFlags]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        V0040OpenapiResp
    """

    return (
        await asyncio_detailed(
            job_id=job_id,
            client=client,
            signal=signal,
            flags=flags,
        )
    ).parsed
